==> cloudt-system-api-0.2.9.1-20240422.035159-2-sources.jar: com/elitescloud/cloudt/system/provider/extend/SysTmplApiRpcService.java <==
package com.elitescloud.cloudt.system.provider.extend;

import com.elitescloud.boot.common.param.FileByteVO;
import com.elitescloud.boot.excel.common.param.ImportRecordDTO;
import com.elitescloud.cloudt.Application;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.system.dto.SysImportRateDTO;
import com.elitescloud.cloudt.system.dto.SysTmplDTO;
import com.elitescloud.cloudt.system.dto.req.RecordResultSaveDTO;
import com.elitesland.cbpl.unicom.annotation.Unicom;
import com.elitesland.cbpl.unicom.domain.InvokeDomain;
import org.springframework.http.HttpEntity;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.mvc.method.annotation.StreamingResponseBody;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.List;
import java.util.Map;

/**
 * 导入导出模板管理接口.
 *
 * @author Kaiser（wang shao）
 * @date 2/17/2023
 */
@Validated
@Unicom(domain = InvokeDomain.SYSTEM, path = SysTmplApiRpcService.URI)
public interface SysTmplApiRpcService {
    String URI = Application.URI_PREFIX + "/tmpl";

    /**
     * 根据模板编号获取模板信息
     *
     * @param code 模板编号
     * @return 模板信息
     */
    @GetMapping(value = "/getByCode")
    ApiResult<SysTmplDTO> getByCode(@RequestParam(name = "code") @NotBlank(message = "模板编码为空") String code);

    /**
     * 下载模板
     *
     * @param code 模板编码
     * @return 模板文件
     * @deprecated 因在OpenFeign中不支持文件流
     */
    @Deprecated(since = "3.2.6")
    @GetMapping(value = "/downloadByCode", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    HttpEntity<StreamingResponseBody> downloadByCode(@RequestParam(name = "code") @NotBlank(message = "模板编码为空") String code);

    /**
     * 获取模板文件模板
     *
     * @param code 模板编码
     * @return 模板文件
     */
    @GetMapping(value = "/getTmplFileByCode")
    ApiResult<FileByteVO> getTmplFileByCode(@RequestParam(name = "code") @NotBlank(message = "模板编码为空") String code);

    /**
     * 根据模板编号获取模板文件的编号
     *
     * @param code 模板编号
     * @return 模板信息
     * @deprecated 请使用 {@link #downloadByCode(String)}
     */
    @Deprecated(since = "3.2.6")
    @GetMapping(value = "/getFileCodeByCode")
    ApiResult<String> getFileCodeByCode(@RequestParam(name = "code") @NotBlank(message = "模板编码为空") String code);

    /**
     * 保存导入导出记录
     *
     * @param code           模板编号
     * @param recordFileCode 导入导出记录的文件编码
     * @param queryParam     导出时的请求参数
     * @return 记录ID
     */
    @PostMapping(value = "/saveRecord")
    ApiResult<Long> saveRecord(@RequestParam(name = "code") @NotBlank(message = "模板编码为空") String code,
                               @RequestParam(name = "recordFileCode", required = false) String recordFileCode,
                               @RequestBody Map<String, Object> queryParam);

    /**
     * 更新总数
     *
     * @param recordId 记录标识
     * @param numTotal 总数
     * @return 记录标识
     */
    @PatchMapping(value = "/record/updateNumTotal")
    ApiResult<Long> updateNumTotal(@RequestParam(name = "recordId") @NotNull(message = "记录标识为空") Long recordId,
                                   @RequestParam(name = "numTotal") @NotNull(message = "总数为空") Long numTotal);

    /**
     * 更新结果
     *
     * @param resultDTO 结果
     * @return 记录标识
     */
    @PutMapping(value = "/record/updateResult")
    ApiResult<Long> updateResult(@RequestBody RecordResultSaveDTO resultDTO);

    /**
     * 获取导入进度
     *
     * @param recordId 记录标识
     * @return 导入进度
     */
    @GetMapping(value = "/record/getRate")
    ApiResult<SysImportRateDTO> getImportRate(@RequestParam(name = "recordId") @NotNull(message = "记录标识为空") Long recordId);

    /**
     * 获取记录的文件标识
     *
     * @param recordId 记录标识
     * @return 文件标识
     */
    @GetMapping(value = "/record/getFileCode")
    ApiResult<String> getRecordFileCode(@RequestParam(name = "recordId") @NotNull(message = "记录标识为空") Long recordId);

    /**
     * 获取未导入结束的记录ID
     *
     * @return 记录ID
     * @deprecated 请使用 {@link #queryUnFinished(String)}
     */
    @GetMapping(value = "/record/getUnfinished")
    @Deprecated(forRemoval = true)
    ApiResult<List<Long>> queryUnFinished();

    /**
     * 获取未导入结束的记录ID
     *
     * @return 记录ID
     */
    @GetMapping(value = "/record/queryUnfinished")
    ApiResult<List<Long>> queryUnFinished(@RequestParam(name = "appCode") @NotBlank(message = "应用编码为空") String appCode);

    /**
     * 更新系统异常导致的记录结果
     *
     * @param appCode 应用编码
     * @param failMsg 异常信息
     * @return 更新结果
     */
    @PutMapping(value = "/record/sysError")
    ApiResult<Boolean> updateResultForSysError(@RequestParam(name = "appCode") @NotBlank(message = "应用编码为空") String appCode,
                                               @RequestParam(name = "failMsg", required = false) String failMsg);

    /**
     * 保存导出文件
     *
     * @param recordId 记录ID
     * @param fileCode 文件标识
     * @param order    顺序
     * @return 结果
     */
    @PatchMapping(value = "/record/saveFile")
    ApiResult<Long> saveExportFile(@RequestParam(name = "recordId") @NotNull(message = "记录标识为空") Long recordId,
                                   @RequestParam(name = "fileCode") @NotBlank(message = "文件标识为空") String fileCode,
                                   @RequestParam(name = "order") @NotNull(message = "顺序为空") Integer order);

    /**
     * 保存失败记录文件
     *
     * @param recordId     导入记录ID
     * @param failFileCode 失败记录文件编码
     * @return 导入记录ID
     */
    @PatchMapping(value = "/record/failFileCode")
    ApiResult<Long> saveImportFailRecord(@RequestParam(name = "recordId") @NotNull(message = "记录标识为空") Long recordId,
                                         @RequestParam(name = "fileCode") @NotBlank(message = "文件标识为空") String failFileCode);

    /**
     * 查询记录
     *
     * @param tmplCode 模板编码
     * @param hours    小时数，默认72小时
     * @param self     是否只查自己的，默认是
     * @return 记录列表
     */
    @GetMapping(value = "/record/query")
    ApiResult<List<ImportRecordDTO>> queryRecord(@RequestParam(name = "tmplCode") @NotBlank(message = "模板编码为空") String tmplCode,
                                                 @RequestParam(name = "hours", required = false, defaultValue = "72") Integer hours,
                                                 @RequestParam(name = "self", required = false, defaultValue = "true") Boolean self);
}

==> cloudt-system-api-3.0.15.0.6-20230303.084838-1-sources.jar: com/elitescloud/cloudt/system/provider/extend/SysTmplApiRpcService.java <==
package com.elitescloud.cloudt.system.provider.extend;

import com.elitescloud.cloudt.Application;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.system.dto.SysImportRateDTO;
import com.elitescloud.cloudt.system.dto.SysTmplDTO;
import com.elitescloud.cloudt.system.dto.req.RecordResultSaveDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.List;
import java.util.Map;

/**
 * 导入导出模板管理接口.
 *
 * @author Kaiser（wang shao）
 * @date 2/17/2023
 */
@FeignClient(name = Application.NAME, path = SysTmplApiRpcService.URI)
@Validated
public interface SysTmplApiRpcService {
    String URI = Application.URI_PREFIX + "/tmpl";

    /**
     * 根据模板编号获取模板信息
     *
     * @param code 模板编号
     * @return 模板信息
     */
    @GetMapping(value = "/getByCode")
    ApiResult<SysTmplDTO> getByCode(@RequestParam(name = "code") @NotBlank(message = "模板编码为空") String code);

    /**
     * 根据模板编号获取模板文件的编号
     *
     * @param code 模板编号
     * @return 模板信息
     */
    @GetMapping(value = "/getFileCodeByCode")
    ApiResult<String> getFileCodeByCode(@RequestParam(name = "code") @NotBlank(message = "模板编码为空") String code);

    /**
     * 保存导入导出记录
     *
     * @param code           模板编号
     * @param recordFileCode 导入导出记录的文件编码
     * @param queryParam     导出时的请求参数
     * @return 记录ID
     */
    @PostMapping(value = "/saveRecord")
    ApiResult<Long> saveRecord(@RequestParam(name = "code") @NotBlank(message = "模板编码为空") String code,
                               @RequestParam(name = "recordFileCode", required = false) String recordFileCode,
                               @RequestBody Map<String, Object> queryParam);

    /**
     * 更新总数
     *
     * @param recordId 记录标识
     * @param numTotal 总数
     * @return 记录标识
     */
    @PatchMapping(value = "/record/updateNumTotal")
    ApiResult<Long> updateNumTotal(@RequestParam(name = "recordId") @NotNull(message = "记录标识为空") Long recordId,
                                   @RequestParam(name = "numTotal") @NotNull(message = "总数为空") Long numTotal);

    /**
     * 更新结果
     *
     * @param resultDTO 结果
     * @return 记录标识
     */
    @PutMapping(value = "/record/updateResult")
    ApiResult<Long> updateResult(@RequestBody RecordResultSaveDTO resultDTO);

    /**
     * 获取导入进度
     *
     * @param recordId 记录标识
     * @return 导入进度
     */
    @GetMapping(value = "/record/getRate")
    ApiResult<SysImportRateDTO> getImportRate(@RequestParam(name = "recordId") @NotNull(message = "记录标识为空") Long recordId);

    /**
     * 获取记录的文件标识
     *
     * @param recordId 记录标识
     * @return 文件标识
     */
    @GetMapping(value = "/record/getFileCode")
    ApiResult<String> getRecordFileCode(@RequestParam(name = "recordId") @NotNull(message = "记录标识为空") Long recordId);

    /**
     * 获取未导入结束的记录ID
     *
     * @return 记录ID
     */
    @GetMapping(value = "/record/getUnfinished")
    ApiResult<List<Long>> queryUnFinished();

    /**
     * 保存导出文件
     *
     * @param recordId 记录ID
     * @param fileCode 文件标识
     * @param order    顺序
     * @return 结果
     */
    @PatchMapping(value = "/record/saveFile")
    ApiResult<Long> saveExportFile(@RequestParam(name = "recordId") @NotNull(message = "记录标识为空") Long recordId,
                                   @RequestParam(name = "fileCode") @NotNull(message = "文件标识为空") String fileCode,
                                   @RequestParam(name = "order") @NotNull(message = "顺序为空") Integer order);
}
